@@ -14,10 +14,8 @@ mod build {
 
         let mut cc = cc::Build::new();
 
-        cc
-            .include(basedir.join("libyara"))
+        cc.include(basedir.join("libyara"))
             .include(basedir.join("libyara/include"))
-
             .file(basedir.join("libyara/ahocorasick.c"))
             .file(basedir.join("libyara/arena.c"))
             .file(basedir.join("libyara/atoms.c"))
@@ -51,7 +49,6 @@ mod build {
             .file(basedir.join("libyara/stream.c"))
             .file(basedir.join("libyara/strutils.c"))
             .file(basedir.join("libyara/threading.c"))
-
             .file(basedir.join("libyara/modules.c"))
             .file(basedir.join("libyara/modules/elf/elf.c"))
             .file(basedir.join("libyara/modules/math/math.c"))
@@ -59,40 +56,48 @@ mod build {
             .file(basedir.join("libyara/modules/pe/pe_utils.c"))
             .file(basedir.join("libyara/modules/tests/tests.c"))
             .file(basedir.join("libyara/modules/time/time.c"))
-
             .define("DEX_MODULE", "")
             .file(basedir.join("libyara/modules/dex/dex.c"))
-
             .define("DOTNET_MODULE", "")
             .file(basedir.join("libyara/modules/dotnet/dotnet.c"))
-
             .define("MACHO_MODULE", "")
             .file(basedir.join("libyara/modules/macho/macho.c"))
-
             .define("NDEBUG", "1");
 
         // Use correct proc functions
         match std::env::var("CARGO_CFG_TARGET_OS").ok().unwrap().as_str() {
-            "windows"
-                => cc.file(basedir.join("libyara/proc/windows.c"))
-                    .define("USE_WINDOWS_PROC", ""),
-            "linux"
-                => cc.file(basedir.join("libyara/proc/linux.c"))
-                    .define("USE_LINUX_PROC", ""),
-            "macos"
-                => cc.file(basedir.join("libyara/proc/mach.c"))
-                    .define("USE_MACH_PROC", ""),
-            _
-                => cc.file(basedir.join("libyara/proc/none.c"))
-                     .define("USE_NO_PROC", ""),
+            "windows" => cc
+                .file(basedir.join("libyara/proc/windows.c"))
+                .define("USE_WINDOWS_PROC", ""),
+            "linux" => cc
+                .file(basedir.join("libyara/proc/linux.c"))
+                .define("USE_LINUX_PROC", ""),
+            "macos" => cc
+                .file(basedir.join("libyara/proc/mach.c"))
+                .define("USE_MACH_PROC", ""),
+            _ => cc
+                .file(basedir.join("libyara/proc/none.c"))
+                .define("USE_NO_PROC", ""),
         };
 
-        if std::env::var("CARGO_CFG_TARGET_FAMILY").ok().unwrap().as_str() != "windows" {
+        if std::env::var("CARGO_CFG_TARGET_FAMILY")
+            .ok()
+            .unwrap()
+            .as_str()
+            != "windows"
+        {
             cc.define("POSIX", "");
         };
 
         // Unfortunately, YARA compilation produces lots of warnings
-        cc.warnings(false);
+        // Ignore some of them.
+        cc.flag_if_supported("-Wno-deprecated-declarations")
+          .flag_if_supported("-Wno-unused-parameter")
+          .flag_if_supported("-Wno-unused-function")
+          .flag_if_supported("-Wno-cast-function-type")
+          .flag_if_supported("-Wno-type-limits")
+          .flag_if_supported("-Wno-tautological-constant-out-of-range-compare")
+          .flag_if_supported("-Wno-sign-compare"); // maybe this one shouldn't be silenced.
 
         cc.compile("yara");
 
@@ -131,7 +136,7 @@ mod build {
     }
 }
 
-#[cfg(feature = "bundled-4_1_0")]
+#[cfg(feature = "bundled-4_1_1")]
 mod bindings {
     use std::env;
     use std::fs;
@@ -139,19 +144,18 @@ mod bindings {
 
     pub fn add_bindings() {
         let binding_file = match env::var("CARGO_CFG_TARGET_FAMILY").unwrap().as_ref() {
-            "unix"    => "yara-4.1.0-unix.rs",
-            "windows"    => "yara-4.1.0-windows.rs",
+            "unix" => "yara-4.1.1-unix.rs",
+            "windows" => "yara-4.1.1-windows.rs",
             f => panic!("no bundled bindings for family {}", f),
         };
-	let out_dir = env::var("OUT_DIR")
-	    .expect("$OUT_DIR should be defined");
-	let out_path = PathBuf::from(out_dir).join("bindings.rs");
-	fs::copy(PathBuf::from("bindings").join(binding_file), out_path)
-	    .expect("Could not copy bindings to output directory");
+        let out_dir = env::var("OUT_DIR").expect("$OUT_DIR should be defined");
+        let out_path = PathBuf::from(out_dir).join("bindings.rs");
+        fs::copy(PathBuf::from("bindings").join(binding_file), out_path)
+            .expect("Could not copy bindings to output directory");
     }
 }
 
-#[cfg(not(feature = "bundled-4_1_0"))]
+#[cfg(not(feature = "bundled-4_1_1"))]
 mod bindings {
     extern crate bindgen;
 
